@@ -277,8 +277,10 @@ impl<'a> Iterator for SourceContentsIter<'a> {
         if self.next_idx >= self.i.get_source_count() {
             None
         } else {
-            self.next_idx += 1;
-            Some(self.i.get_source_contents(self.next_idx))
+            Some(self.i.get_source_contents(self.next_idx).map(|contents| {
+                self.next_idx += 1;
+                contents
+            }))
         }
     }
 }
